package org.gcube.portlets.user.geoportaldataviewer.client;

import java.util.List;

import org.gcube.application.geoportalcommon.shared.GeoNaDataViewerProfile;
import org.gcube.application.geoportalcommon.shared.GeoNaItemRef;
import org.gcube.application.geoportalcommon.shared.gis.BoundsMap;
import org.gcube.application.geoportalcommon.shared.products.ConcessioneDV;
import org.gcube.application.geoportalcommon.shared.products.model.LayerConcessioneDV;
import org.gcube.application.geoportalcommon.shared.products.model.UploadedImageDV;
import org.gcube.portlets.user.geoportaldataviewer.shared.GeoNaSpatialQueryResult;
import org.gcube.portlets.user.geoportaldataviewer.shared.gis.LayerObject;
import org.gcube.portlets.user.geoportaldataviewer.shared.gis.wms.GeoInformationForWMSRequest;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.rpc.AsyncCallback;

public interface GeoportalDataViewerServiceAsync {
	/**
	 * Utility class to get the RPC Async interface from client-side code
	 */
	public static final class Util {
		private static GeoportalDataViewerServiceAsync instance;

		public static final GeoportalDataViewerServiceAsync getInstance() {
			if (instance == null) {
				instance = (GeoportalDataViewerServiceAsync) GWT.create(GeoportalDataViewerService.class);
			}
			return instance;
		}

		private Util() {
			// Utility class should not be instantiated
		}
	}

	void parseWmsRequest(String wmsRequest, String layerName, AsyncCallback<GeoInformationForWMSRequest> callback);

	void getDataResult(List<LayerObject> layerObjects, String mapSrsName, BoundsMap mapBBOX, int maxWFSFeature, double zoomLevel,
			AsyncCallback<List<GeoNaSpatialQueryResult>> callback);

	void getConcessioneForId(String mongoId, AsyncCallback<ConcessioneDV> callback);

	void getMyLogin(AsyncCallback<String> callback);

	void getLayerForType(String layerType, AsyncCallback<GeoInformationForWMSRequest> callback);

	void getGeoNaDataViewProfile(AsyncCallback<GeoNaDataViewerProfile> callback);

	void getUploadedImagesForId(String itemType, String itemId, Integer maxImages,
			AsyncCallback<List<UploadedImageDV>> callback);

	void getPublicLinksFor(GeoNaItemRef item, AsyncCallback<GeoNaItemRef> asyncCallback);

	void getLayersForId(String itemType, String itemId,
			AsyncCallback<List<LayerConcessioneDV>> asyncCallback);

	void getWFSFeatures(List<LayerObject> layerObjects, String mapSrsName, BoundsMap selectBBOX, int maxWFSFeature,
			double zoomLevel, AsyncCallback<List<GeoNaSpatialQueryResult>> callback);

}
